#Vector.py
import math

class Vec2:
    """
        Homegrown class for vector arithmetic.
    """

    def __init__(self, myX, myY):
        """
            Has 2 components x and y.
        """
        self.x = myX
        self.y = myY

    def add(self, other):
        """
            Add other componentwise to this vector in place.
        """
        self.x += other.x
        self.y += other.y

    def subtract(self, other):
        """
            Subtract other componentwise from this vector in place.
        """
        self.x -= other.x
        self.y -= other.y

    def limit(self, scalar):
        """
            Don't let the magnitude of this vector exceed "scalar".
        """
        mag = self.magnitude()
        if mag > scalar:
            self.normalize()
            self.multiply(scalar)

    def magnitude(self):
        """
            Return the magnitude of this vector.
        """
        return math.sqrt(math.pow(self.x, 2) + math.pow(self.y, 2))

    def normalize(self):
        """
            Set the magnitude of this vector to be 1.0.
        """
        m = self.magnitude()
        if m > 0:
            self.x /= m
            self.y /= m

    def multiply(self, scalar):
        """
            Multiply this vector componentwise in place by a scalar.
        """
        self.x *= scalar
        self.y *= scalar
