#engine.Driver.py

import pygame
from pygame.locals import *
import os, sys
import pygame.time

class Driver:
	"""
		Sets up the main game loop.  The driver class is responsible for setting up the display, keeping track of the gametime, and passing any events to the game.  It can contain one or more scenes, which can are the different screens for an application.  For example, there could be a scene for the options menu, the start screen, and the game itself.
	"""

	
	def __init__(self, width, height):
		"""
			Create a display and game engine with the specified resolution.
		"""
		pygame.init()
		self.screen = pygame.display.set_mode((width, height), pygame.HWSURFACE, 32)
		self.scenes = []
		self.clock = pygame.time.Clock()
		
	def addScene(self, scene):
		"""
			Add the specified "scene" to the list of gameworlds.
		"""
		scene.setController(self)
		self.scenes.append(scene)
	
	def setGame(self, logic):
		"""
			Change the current scene to "logic."
		"""
		self.current = logic
		
	def getScene(self, index):
		"""
			Returns the scene at "index."
		"""
		return self.scenes[index]
		
	def changeScene(self, index):
		"""
			Change the current scene to the scene at "index."
		"""
		self.current = self.scenes[index]
		
	def main(self):
		"""
			Runs the main game loop.  Loops around infinitely doing the following tasks:
			- handle input
			- update game logic
			- draw game sprites to the screen
		"""
		pygame.display.flip()
		
		# infinite game loop
		while 1:
			
			# handle input
			for event in pygame.event.get():
				self.current.handleEvent(event)
							
			# update game logic
			self.current.tick(self.clock.tick(40))
			
			# draw sprites
			self.current.draw(self.screen)
			pygame.display.flip()
